@@ -1812,7 +1812,10 @@ class PortageState():
                     for dirdata in self.getpathdata(dfn):
                         yield dirdata
             else:
-                yield readFile(fn)
+                try:
+                    yield readFile(fn)
+                except UnicodeDecodeError as e:
+                    pass
 
     def get_state(self):
         m = hashlib.md5()
